package com.tutorialesprogramacionya.compose20

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.Card
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import java.text.DecimalFormat


class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            Listado(paises = paises)
        }
    }
}

data class Pais(val nombre: String, val cantidadHabitantes: Int, val bandera: Int)

val paises = listOf<Pais>(
    Pais("Argentina", 44000000, R.drawable.argentina),
    Pais("Brasil", 211000000, R.drawable.brasil),
    Pais("Colombia", 50000000, R.drawable.colombia)
)

@Composable
fun Listado(paises: List<Pais>) {
    LazyColumn {
        items(paises) { pais ->
            Tarjeta(pais)
        }
    }
}

@Composable
fun Tarjeta(pais: Pais) {
    Card(
        elevation = 5.dp,
        modifier = Modifier
            .padding(10.dp)
            .fillMaxWidth()
    ) {
        Row(modifier = Modifier.padding(6.dp)) {
            Image(
                painter = painterResource(id = pais.bandera),
                contentDescription = null,
                contentScale = ContentScale.Crop,
            )
            Spacer(modifier = Modifier.width(10.dp))
            Column() {
                Text(
                    text = pais.nombre,
                    style = MaterialTheme.typography.h3
                )
                Text(
                    text = "${DecimalFormat("###,###,###").format(pais.cantidadHabitantes)} habitantes",
                    style = MaterialTheme.typography.body1
                )
            }

        }
    }
}

